@@ -11,7 +11,7 @@ use List::Util qw(shuffle);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-08-20'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.284'; # VERSION
+our $VERSION = '0.285'; # VERSION
 
 our %SPEC;
 
@@ -219,6 +219,7 @@ _
                 'list_selected',
                 'grep',
                 'stat',
+                'test',
             ]],
             default => 'grep',
             cmdline_aliases => {
@@ -237,6 +238,11 @@ _
                     is_flag => 1,
                     code => sub { my $args=shift; $args->{action} = 'stat' },
                 },
+                t => {
+                    summary=>'Test whether words exists in wordlist',
+                    is_flag => 1,
+                    code => sub { my $args=shift; $args->{action} = 'test' },
+                },
             },
             description => <<'_',
 
@@ -256,6 +262,9 @@ wordlists and print them.
 Action `stat` (shortcut option `-s`) will show statistics about all the selected
 wordlists.
 
+Action `test` (shortcut option `-t`) will check whether words are in one of the
+wordlist, using `word_exists()` method on each wordlist.
+
 
 _
         },
@@ -418,12 +427,19 @@ _
             tags => ['category:action-list-cpan'],
         },
         {
-            argv => [qw/-s ID::KBBI/],
+            argv => [qw/-w ID::KBBI -s/],
             summary => 'Show statistics of a wordlist module',
             test => 0,
             'x.doc.show_result' => 0,
             tags => ['category:action-stat'],
         },
+        {
+            argv => [qw/-w Password::RockYou::BloomOnly -t foobar 123456 someGoodPass923/],
+            summary => 'Check some passwords against a password wordlist',
+            test => 0,
+            'x.doc.show_result' => 0,
+            tags => ['category:action-stat'],
+        },
     ],
     'cmdline.default_format' => 'text-simple',
     'x.doc.faq' => <<'_',
@@ -488,7 +504,7 @@ sub wordlist {
     my $use_color = ($color eq 'always' ? 1 : $color eq 'never' ? 0 : undef)
         // $ENV{COLOR} // (-t STDOUT);
 
-    if ($action eq 'grep' || $action eq 'stat' || $action eq 'list_selected') {
+    if ($action eq 'grep' || $action eq 'stat' || $action eq 'list_selected' || $action eq 'test') {
         # convert /.../ in arg to regex
         for (@$arg) {
             $_ = Encode::decode('UTF-8', $_);
@@ -568,6 +584,32 @@ sub wordlist {
             return [200, "OK", \%all_stats];
         }
 
+        if ($action eq 'test') {
+            my @words = @{ $args{arg} };
+            my $res = [200, "OK", [], {'table.fields'=>[qw/word found_in/]}];
+
+          WORDLIST:
+            for my $wl (@$wordlists) {
+                last unless @words;
+                my $wl_obj;
+                eval {
+                    $wl_obj = Module::Load::Util::instantiate_class_with_optional_args(
+                        {ns_prefix=>"WordList"}, $wl);
+                };
+                if ($@) {
+                    warn;
+                    next WORDLIST;
+                }
+                for my $i (reverse (0 .. $#words)) {
+                    if ($wl_obj->word_exists($words[$i])) {
+                        push @{$res->[2]}, {word=>$words[$i], found_in=>$wl};
+                    }
+                }
+            } # for WORDLIST
+
+            return $res;
+        }
+
         # optimize random picking when there's only one wordlist to pick from
         if ($random && @$wordlists == 1 && $num > 0 && $num <= 100) {
             my $wl_obj = Module::Load::Util::instantiate_class_with_optional_args(
@@ -758,7 +800,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.284 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
+This document describes version 0.285 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
 
 =head1 SYNOPSIS
 
@@ -855,7 +897,15 @@ Examples:
 
 =item * Show statistics of a wordlist module:
 
- wordlist(arg => ["ID::KBBI"], action => "stat");
+ wordlist(action => "stat", wordlists => ["ID::KBBI"]);
+
+=item * Check some passwords against a password wordlist:
+
+ wordlist(
+     arg => ["foobar", 123456, "someGoodPass923"],
+   action => "test",
+   wordlists => ["Password::RockYou::BloomOnly"]
+ );
 
 =back
 
@@ -883,6 +933,9 @@ wordlists and print them.
 Action C<stat> (shortcut option C<-s>) will show statistics about all the selected
 wordlists.
 
+Action C<test> (shortcut option C<-t>) will check whether words are in one of the
+wordlist, using C<word_exists()> method on each wordlist.
+
 =item * B<arg> => I<array[str]>
 
 =item * B<chars_ordered> => I<str>
